#' @import knitr
#' @import rmarkdown
#'
#' @noRd
#'
utils::globalVariables(c(
  "tipping_point", "parameter", "TRT01P", "EVENT", "impute", "EVENT", "AVAL",
  "a", "b", "imp", "MAXAVAL", "cdf", "U", "percentile_label", "AVAL_to_impute", "EVENT_to_impute",
  "rep_sample", "time", "survival_comb", "HR", "HR_lowerCI", "HR_upperCI", "CNSRRS", "surv", "rate", "fup"
))
