% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_tp_2d.R
\name{plot_tp_2d}
\alias{plot_tp_2d}
\title{Heatmap of Two-Dimensional Tipping Point Analysis}
\usage{
plot_tp_2d(
  tipse,
  title = "Two-Dimensional Tipping Point Analysis",
  subtitle = NULL,
  xlab = NULL,
  ylab = NULL,
  cross = TRUE,
  line = TRUE
)
}
\arguments{
\item{tipse}{A \code{tipse} object returned by \link{tipping_point_model_based}
or \link{tipping_point_model_free} with \code{impute} of length 2.}

\item{title}{Optional character string specifying the plot title. Set to \code{NULL}
to remove the title.}

\item{subtitle}{Optional character string specifying the plot subtitle. If \code{NULL},
a default subtitle including the method and tipping point is used.}

\item{xlab}{Optional character string specifying the x-axis label. If \code{NULL},
a method-specific default is used.}

\item{ylab}{Optional character string specifying the y-axis label. Defaults to
\code{"Hazard Ratio"}.}

\item{cross}{Optional logical to specifying if tipping points will be marked with a cross.}

\item{line}{Optional logical to specifying if tipping line will be marked with a contour.}
}
\value{
A \code{ggplot2} object.
}
\description{
Visualises the upper confidence limit of the hazard ratio across a Cartesian
grid of two imputation parameters (one per arm). Cells are shaded by
\code{HR_upperCL}, with the tipping line (where \code{HR_upperCI} crosses 1)
highlighted by a dashed contour line and flagged cells marked with a cross.
}
\keyword{internal}
